"use strict";
var path = require('path');
var electron_1 = require('electron');
var menu = require('./menu');
var config_1 = require('./config');
var watcher_1 = require('./watcher');
var loading = config_1.default().then(function (config) { return [config, new watcher_1.default(config)]; });
if (process.argv.indexOf('--version') !== -1) {
    var versions = process.versions;
    console.log("Shiba v" + electron_1.app.getVersion() + ": Rich markdown previewer\n\nUsage:\n  $ shiba [--detach|--version] [{direcotyr/file to watch}]\n\nEnvironment:\n  OS:       " + process.platform + "-" + process.arch + "\n  Electron: " + versions.electron + "\n  Chrome:   " + versions.chrome + "\n  Node.js:  " + versions.node + "\n");
    electron_1.app.quit();
}
electron_1.app.on('window-all-closed', function () { electron_1.app.quit(); });
electron_1.app.on('ready', function () {
    loading.then(function (loaded) {
        var config = loaded[0], dog = loaded[1];
        global.config = config;
        var display_size = electron_1.screen.getPrimaryDisplay().workAreaSize;
        function getConfigLength(key) {
            var len = config[key];
            var default_len = config_1.default_config[key];
            switch (typeof len) {
                case 'string': {
                    if (len === 'max') {
                        return display_size[key];
                    }
                    return default_len;
                }
                case 'number': {
                    return len;
                }
                default: {
                    return default_len;
                }
            }
        }
        var icon_path = path.join(__dirname, '..', '..', 'images', 'shibainu.png');
        var options = {
            icon: icon_path,
            width: getConfigLength('width'),
            height: getConfigLength('height'),
            autoHideMenuBar: config.hide_menu_bar,
        };
        if (config.hide_title_bar) {
            options.titleBarStyle = 'hidden-inset';
        }
        var win = new electron_1.BrowserWindow(options);
        var html = 'file://' + path.join(__dirname, '..', '..', 'static', 'index.html');
        win.loadURL(html);
        dog.wakeup(win.webContents);
        win.on('closed', function () {
            win = null;
        });
        win.on('will-navigate', function (e, url) {
            e.preventDefault();
            electron_1.shell.openExternal(url);
        });
        menu.build(win);
        if (process.argv[0].endsWith('Electron') && process.platform === 'darwin') {
            electron_1.app.dock.setIcon(icon_path);
        }
        if (process.env.NODE_ENV === 'development') {
            win.webContents.on('devtools-opened', function () { return setImmediate(function () { return win.focus(); }); });
            win.webContents.openDevTools({ detach: true });
        }
    }).catch(function (e) {
        console.error('Unknown error: ', e);
        electron_1.app.quit();
    });
});
//# sourceMappingURL=mainu.js.map